@@ -36,10 +36,10 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "6.6.0"
+#define SUNDIALS_VERSION "6.6.1"
 #define SUNDIALS_VERSION_MAJOR 6
 #define SUNDIALS_VERSION_MINOR 6
-#define SUNDIALS_VERSION_PATCH 0
+#define SUNDIALS_VERSION_PATCH 1
 #define SUNDIALS_VERSION_LABEL ""
 #define SUNDIALS_GIT_VERSION ""
 
@@ -105,6 +105,29 @@
 #define SUNDIALS_MAX_SPRINTF_SIZE 
 #endif
 
+/* Build metadata */
+#define SUN_C_COMPILER "GNU"
+#define SUN_C_COMPILER_VERSION "12.1.0"
+#define SUN_C_COMPILER_FLAGS "-march=armv8-a -O2 -pipe -fstack-protector-strong -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=2 -Wformat -Werror=format-security         -fstack-clash-protection"
+
+#define SUN_CXX_COMPILER ""
+#define SUN_CXX_COMPILER_VERSION ""
+#define SUN_CXX_COMPILER_FLAGS ""
+
+#define SUN_FORTRAN_COMPILER ""
+#define SUN_FORTRAN_COMPILER_VERSION ""
+#define SUN_FORTRAN_COMPILER_FLAGS ""
+
+#define SUN_BUILD_TYPE ""
+
+#define SUN_JOB_ID "20230907095319"
+#define SUN_JOB_START_TIME "20230907095319"
+
+#define SUN_TPL_LIST "MPI;OPENMP;KLU;PTHREAD"
+#define SUN_TPL_LIST_SIZE ""
+
+#define SUNDIALS_SPACK_VERSION ""
+
 /* ------------------------------------------------------------------
  * SUNDIALS TPL macros
  * -----------------------------------------------------------------*/
@@ -112,6 +135,88 @@
 /* Caliper */
 /* #undef SUNDIALS_CALIPER_ENABLED */
 
+/* Adiak */
+/* #undef SUNDIALS_ADIAK_ENABLED */
+
+/* Ginkgo */
+/* #undef SUNDIALS_GINKGO_ENABLED */
+#define SUN_GINKGO_VERSION ""
+
+/* HYPRE */
+/* #undef SUNDIALS_HYPRE_ENABLED */
+#define SUN_HYPRE_VERSION ""
+
+/* KLU */
+#define SUNDIALS_KLU_ENABLED
+#define SUN_KLU_VERSION ""
+
+/* KOKKOS */
+/* #undef SUNDIALS_KOKKOS_ENABLED */
+#define SUN_KOKKOS_VERSION ""
+
+/* KOKKOS_KERNELS */
+/* #undef SUNDIALS_KOKKOS_KERNELS_ENABLED */
+#define SUN_KOKKOS_KERNELS_VERSION ""
+
+/* LAPACK */
+/* #undef SUNDIALS_BLAS_LAPACK_ENABLED */
+#define SUN_LAPACK_VERSION ""
+
+/* MAGMA */
+/* #undef SUNDIALS_MAGMA_ENABLED */
+#define SUN_MAGMA_VERSION ""
+
+/* MPI */
+#define SUN_MPI_C_COMPILER "/usr/bin/mpicc"
+#define SUN_MPI_C_VERSION "3.1"
+
+#define SUN_MPI_CXX_COMPILER ""
+#define SUN_MPI_CXX_VERSION ""
+
+#define SUN_MPI_FORTRAN_COMPILER ""
+#define SUN_MPI_FORTRAN_VERSION ""
+
+/* ONEMKL */
+/* #undef SUNDIALS_ONEMKL_ENABLED */
+#define SUN_ONEMKL_VERSION ""
+
+/* OpenMP */
+#define SUNDIALS_OPENMP_ENABLED
+#define SUN_OPENMP_VERSION ""
+
+/* PETSC */
+/* #undef SUNDIALS_PETSC_ENABLED */
+#define SUN_PETSC_VERSION ""
+
+/* PTHREADS */
+/* #undef SUNDIALS_PTHREADS_ENABLED */
+#define SUN_PTHREADS_VERSION ""
+
+/* RAJA */
+/* #undef SUNDIALS_RAJA_ENABLED */
+#define SUN_RAJA_VERSION ""
+
+/* SUPERLUDIST */
+/* #undef SUNDIALS_SUPERLUDIST_ENABLED */
+#define SUN_SUPERLUDIST_VERSION ""
+
+/* SUPERLUMT */
+/* #undef SUNDIALS_SUPERLUMT_ENABLED */
+#define SUN_SUPERLUMT_VERSION ""
+
+/* TRILLINOS */
+/* #undef SUNDIALS_TRILLINOS_ENABLED */
+#define SUN_TRILLINOS_VERSION ""
+
+/* XBRAID */
+/* #undef SUNDIALS_XBRAID_ENABLED */
+#define SUN_XBRAID_VERSION ""
+
+/* RAJA backends */
+/* #undef SUNDIALS_RAJA_BACKENDS_CUDA */
+/* #undef SUNDIALS_RAJA_BACKENDS_HIP */
+/* #undef SUNDIALS_RAJA_BACKENDS_SYCL */
+
 /* Ginkgo backends */
 /* #undef SUNDIALS_GINKGO_BACKENDS_CUDA */
 /* #undef SUNDIALS_GINKGO_BACKENDS_HIP */
@@ -142,10 +247,21 @@
  */
 /* #undef SUNDIALS_TRILINOS_HAVE_MPI */
 
-/* RAJA backends */
-/* #undef SUNDIALS_RAJA_BACKENDS_CUDA */
-/* #undef SUNDIALS_RAJA_BACKENDS_HIP */
-/* #undef SUNDIALS_RAJA_BACKENDS_SYCL */
+
+/* ------------------------------------------------------------------
+ * SUNDIALS language macros
+ * -----------------------------------------------------------------*/
+
+/* CUDA */
+/* #undef SUNDIALS_CUDA_ENABLED */
+#define SUN_CUDA_VERSION ""
+#define SUN_CUDA_COMPILER ""
+#define SUN_CUDA_ARCHITECTURES ""
+
+/* HIP */
+/* #undef SUNDIALS_HIP_ENABLED */
+#define SUN_HIP_VERSION ""
+#define SUN_AMDGPU_TARGETS ""
 
 /* SYCL options */
 /* #undef SUNDIALS_SYCL_2020_UNSUPPORTED */
